@@ -8,6 +8,7 @@
 """
 from bson.objectid import ObjectId
 from pymongo import UpdateOne
+from urllib import parse
 import showlog
 import pymongo
 import time
@@ -47,7 +48,7 @@ class Basics:
         self.host = host
         self.port = port
         self.username = username
-        self.password = password
+        self.password = parse.quote(password)  # 针对pymongo==4.0.1的更新
         self.db = db
         self.collection = collection
         if self.username is None and self.password is None:
